import type { List } from '@/types/List'
import { baseApi, restApiRoutes } from '@/config/routes'

export const getLists = async(): Promise<List[] | null> => {
  try {
    const { data } = await baseApi.get(restApiRoutes.list.base)
    return data
  }
  catch (e) {
    return null
  }
}

export const createList = async(name: string): Promise<List | null> => {
  try {
    const { data } = await baseApi.post(restApiRoutes.list.base, { name })
    return data
  }
  catch (e) {
    return null
  }
}

export const getListById = async(id: string): Promise<List | null> => {
  try {
    const { data } = await baseApi.get(
      restApiRoutes.list.detail.replace('{id}', id),
    )
    return data
  }
  catch (e) {
    return null
  }
}

export const updateList = async(list: List): Promise<List | null> => {
  try {
    const { data } = await baseApi.put(
      restApiRoutes.list.detail.replace('{id}', list.id.toString()),
      list
    )

    return data
  }
  catch (e) {
    return null
  }
}

export const deleteList = async(id: number): Promise<boolean> => {
  try {
    const { data } = await baseApi.delete(
      restApiRoutes.list.detail.replace('{id}', id.toString())
    )
    return !!data
  }
  catch (e) {
    return false
  }
}
