import type { RouteRecordRaw } from 'vue-router'
import { createRouter, createWebHistory } from 'vue-router'
import { storeToRefs } from 'pinia'
import { useListStore } from '@/stores/list'
import NotFound from '@/pages/NotFound.vue'
import Base from '@/pages/Base.vue'
import ListDetail from '@/pages/ListDetail.vue'

const routes: RouteRecordRaw[] = [
  {
    path: '/:locale(en)?',
    name: 'Locale',
    children: [
      {
        path: '',
        name: 'Base',
        component: Base,
      },
      {
        path: 'list/:id([0-9]+)/',
        name: 'List',
        component: ListDetail,
        meta: {
          homeLink: true
        },
        beforeEnter: async({ params: { id } }) => {
          const listStore = useListStore()
          const { list } = storeToRefs(listStore)
          const { fetchList } = listStore
          if (!list.value || list.value.id.toString() !== id)
            await fetchList(id as string)
          if (!list.value)
            return { name: 'Base' }
        }
      }
    ]
  },
  { path: '/:pathMatch(.*)*', name: 'NotFound', component: NotFound }
]

const router = createRouter({
  history: createWebHistory(import.meta.env.BASE_URL),
  routes
})

export default router
