import type { ComputedRef } from 'vue'
import { computed, ref } from 'vue'
import { defineStore } from 'pinia'
import type { List } from '@/types/List'
import { getListById, updateList } from '@/api/lists'
import type { Item } from '@/types/Item'

export enum ItemFilterState {
  ACTIVE= 0,
  COMPLETED = 1,
  ALL = 2
}

export const useListStore = defineStore('list', () => {
  const list = ref<List | null>(null)
  const activeFilterState = ref(ItemFilterState.ALL)

  const filteredItems: ComputedRef<Item[]> = computed(() => {
    if (activeFilterState.value === ItemFilterState.ALL)
      return list.value?.items ?? []
    return list.value?.items?.filter(item => item.completed === !!activeFilterState.value) ?? []
  })

  const fetchList = async(id: string) => list.value = await getListById(id)
  const deleteItem = async(id: number) => {
    if (!list.value)
      return
    const items: Item[] = list.value?.items?.filter(item => item.id !== id) ?? []
    const _list: List = { ...list.value, items }
    list.value = await updateList(_list)
  }

  const addItem = async(item: Item) => {
    if (!list.value)
      return false
    const items: Item[] = [...list.value?.items ?? [], item]
    const _list: List = { ...list.value, items }
    const data = await updateList(_list)
    if (!data)
      return false
    list.value = data
    return true
  }

  const toggleStatus = async(id: number) => {
    if (!list.value || !list.value.items)
      return
    const items: Item[] = [...list.value.items]
    const indexOfItem = items.findIndex(item => item.id === id)
    if (indexOfItem < 0)
      return
    items[indexOfItem].completed = !items[indexOfItem].completed
    const _list: List = { ...list.value, items }
    list.value = await updateList(_list)
  }

  return { list, filteredItems, activeFilterState, fetchList, deleteItem, addItem, toggleStatus }
})
