import { ref } from 'vue'
import { defineStore } from 'pinia'
import type { List } from '@/types/List'
import { createList as createListApi, deleteList as deleteListApi, getLists } from '@/api/lists'

export const useListsStore = defineStore('lists', () => {
  const lists = ref<List[] | null>(null)

  const fetchLists = async() => lists.value = await getLists()
  const deleteList = async(id: number) => {
    const success = await deleteListApi(id)
    if (!success)
      return
    lists.value = lists.value?.filter(list => list.id !== id) ?? null
  }
  const createList = async(name: string) => {
    if (lists.value?.some(list => list.name === name))
      return false
    const createdList = await createListApi(name)
    if (!createdList)
      return false
    lists.value = [...lists.value ?? [], createdList]
    return true
  }

  return { lists, fetchLists, deleteList, createList }
})
